@@ -188,7 +188,7 @@ panel.levelplot <-
                       width = lx[idx] * scaleWidth(z, shrinkx[1], shrinkx[2], fullZrange),
                       height = ly[idy] * scaleWidth(z, shrinky[1], shrinky[2], fullZrange),
                       default.units = "native",
-                      gp = gpar(fill = col.regions[zcol], col = NULL, alpha = alpha.regions))
+                      gp = gpar(fill=col.regions[zcol], col = NULL, alpha = alpha.regions))
 
         if (contour)
         {
@@ -318,43 +318,31 @@ panel.levelplot <-
 }
 
 
-contourplot <- function(x, ...)
-{
-    ocall <- match.call()
-    formula <- ocall$formula
-    if (!is.null(formula))
-    {
-        warning("The 'formula' argument has been renamed to 'x'. See ?xyplot")
-        ocall$formula <- NULL
-        if (is.null(ocall$x)) ocall$x <- formula
-        eval(ocall, parent.frame())
-    }
-    else UseMethod("contourplot")
-}
+contourplot <- function(formula, ...)  UseMethod("contourplot")
 
 
 
 contourplot.matrix <-
-    function(x, data = NULL, aspect = "iso", ...)
+    function(formula, data = NULL, aspect = "iso", ...)
 {
     if (!missing(data)) warning("explicit data specification ignored")
     form <- z ~ row * column
     data <-
-        expand.grid(row = seq(length = nrow(x)),
-                    column = seq(length = ncol(x)))
-    data$z <- as.vector(as.numeric(x))
+        expand.grid(row = seq(length = nrow(formula)),
+                    column = seq(length = ncol(formula)))
+    data$z <- as.vector(as.numeric(formula))
     ## if rownames/colnames are non-null, make them factors
-    if (!is.null(rownames(x)))
-        data$row <- factor(data$row, labels = rownames(x))
-    if (!is.null(colnames(x)))
-        data$column <- factor(data$column, labels = colnames(x))
+    if (!is.null(rownames(formula)))
+        data$row <- factor(data$row, labels = rownames(formula))
+    if (!is.null(colnames(formula)))
+        data$column <- factor(data$column, labels = colnames(formula))
     contourplot(form, data, aspect = aspect, ...)
 }
 
 
 
 contourplot.formula <-
-    function(x,
+    function(formula,
              data = parent.frame(),
              panel = "panel.contourplot",
              cuts = 7,
@@ -426,39 +414,27 @@ contourplot.formula <-
 ##               dots))
 ## }
 
-levelplot <- function(x, ...)
-{
-    ocall <- match.call()
-    formula <- ocall$formula
-    if (!is.null(formula))
-    {
-        warning("The 'formula' argument has been renamed to 'x'. See ?xyplot")
-        ocall$formula <- NULL
-        if (is.null(ocall$x)) ocall$x <- formula
-        eval(ocall, parent.frame())
-    }
-    else UseMethod("levelplot")
-}
+levelplot <- function(formula, ...)  UseMethod("levelplot")
 
 levelplot.matrix <-
-    function(x, data = NULL, aspect = "iso", ...)
+    function(formula, data = NULL, aspect = "iso", ...)
 {
     if (!missing(data)) warning("explicit data specification ignored")
     form <- z ~ row * column
     data <-
-        expand.grid(row = seq(length = nrow(x)),
-                    column = seq(length = ncol(x)))
-    data$z <- as.vector(as.numeric(x))
+        expand.grid(row = seq(length = nrow(formula)),
+                    column = seq(length = ncol(formula)))
+    data$z <- as.vector(as.numeric(formula))
     ## if rownames/colnames are non-null, make them factors
-    if (!is.null(rownames(x)))
-        data$row <- factor(data$row, labels = rownames(x))
-    if (!is.null(colnames(x)))
-        data$column <- factor(data$column, labels = colnames(x))
+    if (!is.null(rownames(formula)))
+        data$row <- factor(data$row, labels = rownames(formula))
+    if (!is.null(colnames(formula)))
+        data$column <- factor(data$column, labels = colnames(formula))
     levelplot(form, data, aspect = aspect, ...)
 }
 
 levelplot.formula <-
-    function(x,
+    function(formula,
              data = parent.frame(),
              allow.multiple = is.null(groups) || outer,
              outer = TRUE,
@@ -494,7 +470,7 @@ levelplot.formula <-
     ## Step 1: Evaluate x, y, z etc. and do some preprocessing
 
     form <-
-        latticeParseFormula(x, data, dim = 3,
+        latticeParseFormula(formula, data, dim = 3,
                             subset = subset, groups = groups,
                             multiple = allow.multiple,
                             outer = outer, subscripts = TRUE,
