@@ -49,9 +49,7 @@ panel.splom <-
 
 
 diag.panel.splom <-
-    function(x = NULL,
-
-             varname = NULL, limits, at = NULL, lab = NULL,
+    function(varname = NULL, limits, at = NULL, lab = NULL,
              draw = TRUE,
 
              varname.col = add.text$col,
@@ -144,7 +142,6 @@ diag.panel.splom <-
 
 
 
-## FIXME: add alpha pars
 
 panel.pairs <-
     function(z,
@@ -159,11 +156,11 @@ panel.pairs <-
              subscripts,
              pscales = 5,
 
-             packet.number = 0,  ## should always be supplied
              panel.number = 0,  ## should always be supplied
+             panel.counter = 0,  ## should always be supplied
 
              prepanel.limits = function(x) if (is.factor(x)) levels(x) else
-             extend.limits(range(as.numeric(x), finite = TRUE)),
+             extend.limits(range(as.numeric(x), na.rm = TRUE)),
 
              varname.col = add.text$col,
              varname.cex = add.text$cex,
@@ -180,8 +177,7 @@ panel.pairs <-
              axis.line.col = axis.line$col,
              axis.line.lty = axis.line$lty,
              axis.line.lwd = axis.line$lwd,
-             ## axis.line.alpha = axis.line$alpha,
-             
+
              ...)
 {
     lower.panel <- 
@@ -271,13 +267,10 @@ panel.pairs <-
                     }
                         
 
-                    diag.panel(x = z[subscripts, j],
-                               varname = colnames(z)[i],
+                    diag.panel(varname = colnames(z)[i],
                                limits = lim[[i]],
                                at = axls, lab = labels,
                                draw = draw,
-                               panel.number = panel.number,
-                               packet.number = packet.number,
 
                                varname.col = varname.col,
                                varname.cex = varname.cex,
@@ -293,33 +286,28 @@ panel.pairs <-
 
                                axis.line.col = axis.line.col,
                                axis.line.lty = axis.line.lty,
-                               axis.line.lwd = axis.line.lwd,
-
-                               ...)
+                               axis.line.lwd = axis.line.lwd)
 
                     grid.rect(gp =
                               gpar(col = axis.line.col,
                                    lty = axis.line.lty,
-                                   lwd = axis.line.lwd,
-                                   fill = "transparent"))
+                                   lwd = axis.line.lwd))
 
                 }
                 else
                 {
                     pargs <-
                         if (!panel.subscripts)
-                            c(list(x = z[subscripts, j],
-                                   y = z[subscripts, i],
-                                   panel.number = panel.number,
-                                   packet.number = packet.number),
+                            c(list(x = as.numeric(z[subscripts, j]),
+                                   y = as.numeric(z[subscripts, i]),
+                                   panel.number = panel.number),
                               list(...))
                         else
-                            c(list(x = z[subscripts, j],
-                                   y = z[subscripts, i],
+                            c(list(x = as.numeric(z[subscripts, j]),
+                                   y = as.numeric(z[subscripts, i]),
                                    groups = groups,
                                    subscripts = subscripts,
-                                   panel.number = panel.number,
-                                   packet.number = packet.number),
+                                   panel.number = panel.number),
                               list(...))
 
                     if (!("..." %in% names(formals(panel))))
@@ -335,8 +323,7 @@ panel.pairs <-
                     grid.rect(gp =
                               gpar(col = axis.line.col,
                                    lty = axis.line.lty,
-                                   lwd = axis.line.lwd,
-                                   fill = "transparent"))
+                                   lwd = axis.line.lwd))
                 }
                 upViewport()
             }
@@ -346,29 +333,17 @@ panel.pairs <-
 
 
 
-splom <- function(x, ...)
-{
-    ocall <- match.call()
-    formula <- ocall$formula
-    if (!is.null(formula))
-    {
-        warning("The 'formula' argument has been renamed to 'x'. See ?xyplot")
-        ocall$formula <- NULL
-        if (is.null(ocall$x)) ocall$x <- formula
-        eval(ocall, parent.frame())
-    }
-    else UseMethod("splom")
-}
+splom <- function(formula, ...)  UseMethod("splom")
 
 
 splom.data.frame <-
-    function(x, data = NULL, ...)
+    function(formula, data = NULL, ...)
 {
     ocall <- ccall <- match.call()
     if (!is.null(ccall$data)) 
         warning("explicit data specification ignored")
-    ccall$data <- list(x = x)
-    ccall$x <- ~x
+    ccall$data <- list(x = formula)
+    ccall$formula <- ~x
     ccall[[1]] <- as.name("splom")
     ans <- eval(ccall, parent.frame())
     ans$call <- ocall
@@ -378,7 +353,7 @@ splom.data.frame <-
 
 
 splom.formula <-
-    function(x,
+    function(formula,
              data = parent.frame(),
              auto.key = FALSE,
              aspect = 1,
@@ -408,15 +383,36 @@ splom.formula <-
 
     ## Step 1: Evaluate x, y, etc. and do some preprocessing
 
-    ## right.name <- deparse(substitute(x))
-    ## x <- eval(substitute(x), data, parent.frame())
-
+    ## right.name <- deparse(substitute(formula))
+    ## formula <- eval(substitute(formula), data, parent.frame())
     form <-
-        latticeParseFormula(x, data,
+        ## if (inherits(formula, "formula"))
+        latticeParseFormula(formula, data,
                             subset = subset, groups = groups,
                             multiple = FALSE,
                             outer = FALSE, subscripts = TRUE,
                             drop = drop.unused.levels)
+##         else {
+##             if (is.matrix(formula)) {
+##                 list(left = NULL,
+##                      right = as.data.frame(formula)[subset,],
+##                      condition = NULL,
+##                      left.name = "",
+##                      right.name =  right.name,
+##                      groups = groups,
+##                      subscr = seq(length = nrow(formula))[subset])
+##             }
+##             else if (is.data.frame(formula)) {
+##                 list(left = NULL,
+##                      right = formula[subset,],
+##                      condition = NULL,
+##                      left.name = "",
+##                      right.name =  right.name,
+##                      groups = groups,
+##                      subscr = seq(length = nrow(formula))[subset])
+##             }
+##             else stop("invalid formula")
+##         }
 
 
     ## We need to be careful with subscripts here. It HAS to be there,
@@ -564,7 +560,7 @@ splom.formula <-
     cond.current.level <- rep(1, number.of.cond)
 
 
-    for (packet.number in seq(length = nplots))
+    for (panel.number in seq(length = nplots))
     {
 
         ##id <- !id.na  WHY ?
@@ -579,7 +575,7 @@ splom.formula <-
             else (as.numeric(var) == cond.current.level[i])
         }
 
-        foo$panel.args[[packet.number]] <-
+        foo$panel.args[[panel.number]] <-
             list(subscripts = subscr[id])
 
         cond.current.level <-
@@ -588,20 +584,19 @@ splom.formula <-
     }
 
 
-    more.comp <-
-        c(limits.and.aspect(prepanel.default.splom,
-                            prepanel = prepanel, 
-                            have.xlim = have.xlim, xlim = xlim, 
-                            have.ylim = have.ylim, ylim = ylim, 
-                            x.relation = foo$x.scales$relation,
-                            y.relation = foo$y.scales$relation,
-                            panel.args.common = foo$panel.args.common,
-                            panel.args = foo$panel.args,
-                            aspect = aspect,
-                            nplots = nplots,
-                            x.axs = foo$x.scales$axs,
-                            y.axs = foo$y.scales$axs),
-          cond.orders(foo))
+    more.comp <- c(limits.and.aspect(prepanel.default.splom,
+                                     prepanel = prepanel, 
+                                     have.xlim = have.xlim, xlim = xlim, 
+                                     have.ylim = have.ylim, ylim = ylim, 
+                                     x.relation = foo$x.scales$relation,
+                                     y.relation = foo$y.scales$relation,
+                                     panel.args.common = foo$panel.args.common,
+                                     panel.args = foo$panel.args,
+                                     aspect = aspect,
+                                     nplots = nplots,
+                                     x.axs = foo$x.scales$axs,
+                                     y.axs = foo$y.scales$axs),
+                   cond.orders(foo))
     foo[names(more.comp)] <- more.comp
 
 
